..
  (c) 2020 by flonatel GmbH & Co. KG
  
  SPDX-License-Identifier: GPL-3.0-or-later

  This file is part of rmtoo.
  
  rmtoo is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.
  
  rmtoo is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with rmtoo.  If not, see <https://www.gnu.org/licenses/>.


How to Contribute
=================

We'd love to accept your patches and contributions to this
project. There are just a few small guidelines you need to follow.

Contributor License Agreement
=============================

When you actively push changes to one of our development platforms,
e.g. using a pull or merge request, you agree that your contribution
is placed under GPL3 for the complete project - except the contents of
the docs/template_project folder which is placed under Apache 2
license.

New files must include an appropriate license header - including the
SPDX license identifier.
